@@ -801,3 +801,10 @@ class KiwiShellVariableValueError(KiwiError):
     Exception raised if a given python value cannot be converted
     into a string representation for use in shell scripts
     """
+
+
+class KiwiIncludFileNotFoundError(KiwiError):
+    """
+    Exception raised if the file reference in an <include>
+    statement could not be found
+    """
