@@ -8,9 +8,9 @@ from kiwi.oci_tools.umoci import OCIUmoci
 class TestOCIUmoci:
     @patch('kiwi.oci_tools.umoci.CommandCapabilities.has_option_in_help')
     @patch('kiwi.oci_tools.base.datetime')
-    @patch('kiwi.oci_tools.umoci.mkdtemp')
-    def setup(self, mock_base_mkdtemp, mock_datetime, mock_cmd_caps):
-        mock_base_mkdtemp.return_value = 'tmpdir'
+    @patch('kiwi.oci_tools.umoci.Temporary')
+    def setup(self, mock_Temporary, mock_datetime, mock_cmd_caps):
+        mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         mock_cmd_caps.return_value = True
         strftime = Mock()
         strftime.strftime = Mock(return_value='current_date')
@@ -27,13 +27,16 @@ class TestOCIUmoci:
             call(['umoci', 'new', '--image', 'tmpdir/oci_layout:base_layer'])
         ]
 
-    @patch('kiwi.oci_tools.umoci.mkdtemp')
+    @patch('kiwi.oci_tools.umoci.Temporary')
     @patch('kiwi.oci_tools.umoci.Command.run')
-    def test_unpack(self, mock_Command_run, mock_mkdtemp):
-        mock_mkdtemp.return_value = 'oci_root'
+    def test_unpack(self, mock_Command_run, mock_Temporary):
+        mock_Temporary.return_value.new_dir.return_value.name = 'oci_root'
         self.oci.unpack()
         mock_Command_run.assert_called_once_with(
-            ['umoci', 'unpack', '--image', 'tmpdir/oci_layout:base_layer', 'oci_root']
+            [
+                'umoci', 'unpack', '--image',
+                'tmpdir/oci_layout:base_layer', 'oci_root'
+            ]
         )
 
     @patch('kiwi.oci_tools.base.DataSync')
@@ -67,10 +70,10 @@ class TestOCIUmoci:
             options=['-a', '-H', '-X', '-A', '--one-file-system', '--inplace']
         )
 
-    @patch('kiwi.oci_tools.umoci.mkdtemp')
+    @patch('kiwi.oci_tools.umoci.Temporary')
     @patch('kiwi.oci_tools.umoci.Command.run')
-    def test_repack(self, mock_Command_run, mock_mkdtemp):
-        mock_mkdtemp.return_value = 'oci_root'
+    def test_repack(self, mock_Command_run, mock_Temporary):
+        mock_Temporary.return_value.new_dir.return_value.name = 'oci_root'
         oci_config = {
             'history': {
                 'author': 'history author',
@@ -120,12 +123,12 @@ class TestOCIUmoci:
             ]
         )
 
-    @patch('kiwi.oci_tools.umoci.mkdtemp')
+    @patch('kiwi.oci_tools.umoci.Temporary')
     @patch('kiwi.oci_tools.base.datetime')
     @patch('kiwi.oci_tools.umoci.CommandCapabilities.has_option_in_help')
     @patch('kiwi.oci_tools.umoci.Command.run')
     def test_set_config_with_history(
-        self, mock_Command_run, mock_cmd_caps, mock_datetime, mock_mkdtemp
+        self, mock_Command_run, mock_cmd_caps, mock_datetime, mock_Temporary
     ):
         oci_config = {
             'container_tag': 'tag',
@@ -139,7 +142,7 @@ class TestOCIUmoci:
             'environment': {'FOO': 'bar', 'PATH': '/bin'},
             'labels': {'a': 'value', 'b': 'value'},
         }
-        mock_mkdtemp.return_value = 'tmpdir'
+        mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
         mock_cmd_caps.return_value = False
         strftime = Mock()
         strftime.strftime = Mock(return_value='current_date')
@@ -219,11 +222,3 @@ class TestOCIUmoci:
         mock_Command_run.assert_called_once_with(
             ['umoci', 'gc', '--layout', 'tmpdir/oci_layout']
         )
-
-    @patch('kiwi.oci_tools.umoci.Path')
-    def test_destructor(self, mock_Path):
-        self.oci.oci_root_dir = 'oci_root'
-        self.oci.__del__()
-        assert mock_Path.wipe.call_args_list == [
-            call('oci_root'), call('tmpdir')
-        ]
