@@ -1,6 +1,6 @@
 import logging
 from mock import (
-    patch, Mock, mock_open
+    patch, Mock, mock_open, call
 )
 from pytest import (
     raises, fixture
@@ -39,18 +39,22 @@ class TestResult:
             self.result.print_results()
 
     @patch('pickle.dump')
-    def test_dump(self, mock_pickle_dump):
-
+    @patch('simplejson.dumps')
+    def test_dump(self, mock_simplejson_dumps, mock_pickle_dump):
         m_open = mock_open()
         with patch('builtins.open', m_open, create=True):
             assert self.result.dump('kiwi.result') is None
 
-        m_open.assert_called_once_with(
-            'kiwi.result', 'wb'
-        )
+        assert m_open.call_args_list == [
+            call('kiwi.result', 'wb'),
+            call('kiwi.result.json', 'w')
+        ]
         mock_pickle_dump.assert_called_once_with(
             self.result, m_open.return_value
         )
+        mock_simplejson_dumps.assert_called_once_with(
+            self.result.result_files, sort_keys=True, indent=4
+        )
 
     @patch('pickle.dump')
     def test_dump_failed(self, mock_pickle_dump):
